@@ -3,7 +3,7 @@ from datetime import datetime
 from functools import lru_cache
 from itertools import chain
 from math import ceil
-from typing import Any, Iterator, Dict, List
+from typing import Any, Iterator, Dict, List, Optional
 
 from maggma.builders import Builder
 from maggma.stores import MongoStore
@@ -63,7 +63,7 @@ def generic_groupby(list_in, comp=operator.eq):
         if ls1 is not None:
             continue
         list_out[i1] = label_num
-        for i2, ls2 in list(enumerate(list_out))[i1 + 1:]:
+        for i2, ls2 in list(enumerate(list_out))[(i1 + 1):]:
             if comp(list_in[i1], list_in[i2]):
                 if list_out[i2] is None:
                     list_out[i2] = list_out[i1]
@@ -79,17 +79,17 @@ default_build_settings = EmmetBuildSettings()
 
 class StructureGroupBuilder(Builder):
     def __init__(
-            self,
-            materials: MongoStore,
-            sgroups: MongoStore,
-            working_ion: str,
-            query: dict = None,
-            ltol: float = default_build_settings.LTOL,
-            stol: float = default_build_settings.STOL,
-            angle_tol: float = default_build_settings.ANGLE_TOL,
-            check_newer: bool = True,
-            chunk_size: int = 1000,
-            **kwargs,
+        self,
+        materials: MongoStore,
+        sgroups: MongoStore,
+        working_ion: str,
+        query: Optional[dict] = None,
+        ltol: float = default_build_settings.LTOL,
+        stol: float = default_build_settings.STOL,
+        angle_tol: float = default_build_settings.ANGLE_TOL,
+        check_newer: bool = True,
+        chunk_size: int = 1000,
+        **kwargs,
     ):
         """
         Aggregate materials entries into sgroups that are topotactically similar to each other.
@@ -128,9 +128,7 @@ class StructureGroupBuilder(Builder):
         new_chemsys_list = []
 
         for chemsys in all_chemsys:
-            elements = [
-                element for element in chemsys.split("-") if element != self.working_ion
-            ]
+            elements = [element for element in chemsys.split("-") if element != self.working_ion]
             new_chemsys = "-".join(sorted(elements))
             new_chemsys_list.append(new_chemsys)
 
@@ -139,9 +137,7 @@ class StructureGroupBuilder(Builder):
         for split in grouper(new_chemsys_list, N):
             new_split_add = []
             for chemsys in split:
-                elements = [element for element in chemsys.split("-")] + [
-                    self.working_ion
-                ]
+                elements = [element for element in chemsys.split("-")] + [self.working_ion]
                 new_chemsys = "-".join(sorted(elements))
                 new_split_add.append(new_chemsys)
 
@@ -173,10 +169,7 @@ class StructureGroupBuilder(Builder):
         all_chemsys = self.materials.distinct("chemsys", criteria=base_query)
         # Contains the working ion but not ONLY the working ion
         all_chemsys = [
-            *filter(
-                lambda x: self.working_ion in x and len(x) > 1,
-                [chemsys_.split("-") for chemsys_ in all_chemsys],
-            )
+            *filter(lambda x: self.working_ion in x and len(x) > 1, [chemsys_.split("-") for chemsys_ in all_chemsys],)
         ]
 
         self.logger.debug(
@@ -187,58 +180,32 @@ class StructureGroupBuilder(Builder):
         for chemsys_l in all_chemsys:
             chemsys = "-".join(sorted(chemsys_l))
             chemsys_wo = "-".join(sorted(set(chemsys_l) - {self.working_ion}))
-            chemsys_query = {
-                "$and": [
-                    {"chemsys": {"$in": [chemsys_wo, chemsys]}},
-                    self.query.copy(),
-                ]
-            }
+            chemsys_query = {"$and": [{"chemsys": {"$in": [chemsys_wo, chemsys]}}, self.query.copy()]}
             self.logger.debug(f"QUERY: {chemsys_query}")
             all_mats_in_chemsys = list(
                 self.materials.query(
-                    criteria=chemsys_query,
-                    properties=MAT_PROPS + [self.materials.last_updated_field],
+                    criteria=chemsys_query, properties=MAT_PROPS + [self.materials.last_updated_field],
                 )
             )
-            self.logger.debug(
-                f"Found {len(all_mats_in_chemsys)} materials in {chemsys_wo}"
-            )
+            self.logger.debug(f"Found {len(all_mats_in_chemsys)} materials in {chemsys_wo}")
             if self.check_newer:
                 all_target_docs = list(
                     self.sgroups.query(
                         criteria={"chemsys": chemsys},
-                        properties=[
-                            "group_id",
-                            self.sgroups.last_updated_field,
-                            "material_ids",
-                        ],
+                        properties=["group_id", self.sgroups.last_updated_field, "material_ids"],
                     )
                 )
-                self.logger.debug(
-                    f"Found {len(all_target_docs)} Grouped documents in {chemsys_wo}"
-                )
+                self.logger.debug(f"Found {len(all_target_docs)} Grouped documents in {chemsys_wo}")
 
-                mat_times = [
-                    mat_doc[self.materials.last_updated_field]
-                    for mat_doc in all_mats_in_chemsys
-                ]
+                mat_times = [mat_doc[self.materials.last_updated_field] for mat_doc in all_mats_in_chemsys]
                 max_mat_time = max(mat_times, default=datetime.min)
-                self.logger.debug(
-                    f"The newest material doc was generated at {max_mat_time}."
-                )
+                self.logger.debug(f"The newest material doc was generated at {max_mat_time}.")
 
-                target_times = [
-                    g_doc[self.materials.last_updated_field]
-                    for g_doc in all_target_docs
-                ]
+                target_times = [g_doc[self.materials.last_updated_field] for g_doc in all_target_docs]
                 min_target_time = min(target_times, default=datetime.max)
-                self.logger.debug(
-                    f"The newest GROUP doc was generated at {min_target_time}."
-                )
+                self.logger.debug(f"The newest GROUP doc was generated at {min_target_time}.")
 
-                mat_ids = set(
-                    [mat_doc["material_id"] for mat_doc in all_mats_in_chemsys]
-                )
+                mat_ids = set([mat_doc["material_id"] for mat_doc in all_mats_in_chemsys])
 
                 # If any material id is missing or if any material id has been updated
                 target_ids = set()
@@ -252,9 +219,7 @@ class StructureGroupBuilder(Builder):
                     self.logger.info(f"Skipping chemsys {chemsys}.")
                     yield None
                 elif len(target_ids) == 0:
-                    self.logger.info(
-                        f"No documents in chemsys {chemsys} in the target database."
-                    )
+                    self.logger.info(f"No documents in chemsys {chemsys} in the target database.")
                     yield {"chemsys": chemsys, "materials": all_mats_in_chemsys}
                 else:
                     self.logger.info(
@@ -310,13 +275,13 @@ class StructureGroupBuilder(Builder):
 
 class InsertionElectrodeBuilder(Builder):
     def __init__(
-            self,
-            grouped_materials: MongoStore,
-            thermo: MongoStore,
-            insertion_electrode: MongoStore,
-            query: dict = None,
-            strip_structures: bool = False,
-            **kwargs,
+        self,
+        grouped_materials: MongoStore,
+        thermo: MongoStore,
+        insertion_electrode: MongoStore,
+        query: Optional[dict] = None,
+        strip_structures: bool = False,
+        **kwargs,
     ):
         self.grouped_materials = grouped_materials
         self.insertion_electrode = insertion_electrode
@@ -325,9 +290,7 @@ class InsertionElectrodeBuilder(Builder):
         self.strip_structures = strip_structures
 
         super().__init__(
-            sources=[self.grouped_materials, self.thermo],
-            targets=[self.insertion_electrode],
-            **kwargs,
+            sources=[self.grouped_materials, self.thermo], targets=[self.insertion_electrode], **kwargs,
         )
 
     def prechunk(self, number_splits: int) -> Iterator[Dict]:
@@ -355,29 +318,18 @@ class InsertionElectrodeBuilder(Builder):
             return best_wion
 
         def get_thermo_docs(mat_ids):
-            self.logger.debug(
-                f"Looking for {len(mat_ids)} material_id in the Thermo DB."
-            )
+            self.logger.debug(f"Looking for {len(mat_ids)} material_id in the Thermo DB.")
             self.thermo.connect()
             thermo_docs = list(
                 self.thermo.query(
                     {"$and": [{"material_id": {"$in": mat_ids}}]},
-                    properties=[
-                        "material_id",
-                        "_sbxn",
-                        "thermo",
-                        "entries",
-                        "energy_type",
-                        "energy_above_hull",
-                    ],
+                    properties=["material_id", "_sbxn", "thermo", "entries", "energy_type", "energy_above_hull"],
                 )
             )
 
             self.logger.debug(f"Found for {len(thermo_docs)} Thermo Documents.")
             if len(thermo_docs) != len(mat_ids):
-                missing_ids = set(mat_ids) - set(
-                    [t_["material_id"] for t_ in thermo_docs]
-                )
+                missing_ids = set(mat_ids) - set([t_["material_id"] for t_ in thermo_docs])
                 self.logger.warn(
                     f"The following ids are missing from the entries in thermo {missing_ids}.\n"
                     "The is likely due to the fact that a calculation other than GGA or GGA+U was "
@@ -420,13 +372,9 @@ class InsertionElectrodeBuilder(Builder):
         """
         if item is None:
             return None  # type: ignore
-        self.logger.debug(
-            f"Working on {item['group_id']} with {len(item['thermo_docs'])}"
-        )
+        self.logger.debug(f"Working on {item['group_id']} with {len(item['thermo_docs'])}")
 
-        entries = [
-            tdoc_["entries"][tdoc_["energy_type"]] for tdoc_ in item["thermo_docs"]
-        ]
+        entries = [tdoc_["entries"][tdoc_["energy_type"]] for tdoc_ in item["thermo_docs"]]
 
         entries = list(map(ComputedStructureEntry.from_dict, entries))
 
@@ -434,9 +382,7 @@ class InsertionElectrodeBuilder(Builder):
             item["working_ion_doc"]["entries"][item["working_ion_doc"]["energy_type"]]
         )
 
-        decomp_energies = {
-            d_["material_id"]: d_["energy_above_hull"] for d_ in item["thermo_docs"]
-        }
+        decomp_energies = {d_["material_id"]: d_["energy_above_hull"] for d_ in item["thermo_docs"]}
 
         for ient in entries:
             ient.data["volume"] = ient.structure.volume
@@ -458,9 +404,7 @@ class InsertionElectrodeBuilder(Builder):
         if len(items) > 0:
             self.logger.info("Updating {} battery documents".format(len(items)))
             for struct_group_dict in items:
-                struct_group_dict[
-                    self.grouped_materials.last_updated_field
-                ] = datetime.utcnow()
+                struct_group_dict[self.grouped_materials.last_updated_field] = datetime.utcnow()
             self.insertion_electrode.update(docs=items, key=["battery_id"])
         else:
             self.logger.info("No items to update")
